/*
 * CAfterDark is a base class for developing graphic modules
 * for After Dark.  This class defines the default behaviour
 * for a graphics module - to blank the screen.  Subclasses
 * can add additional behavior. 
 */
 
#include "CAfterDark.h"
 
/*
 * Init does nothing.  Subclasses should override this method to
 * initialize any instance variables and setup the initial state
 * of their graphics module.
 */
OSErr CAfterDark::Init(RgnHandle blankRgn, GMParamBlockPtr params)
{
	return noErr;
}


/*
 * Blank fills the blankRgn with black thus blanking the screen(s).
 * Subclasses should override this method is they a) don't want to
 * blank the screen or b) want to do something else.
 */
OSErr CAfterDark::Blank(RgnHandle blankRgn, GMParamBlockPtr params)
{
	FillRgn(blankRgn, params->qdGlobalsCopy->qdBlack);
	return noErr;
}


/*
 * DrawFrame does nothing.  Subclasses should override this method
 * to perform animation.
 */
OSErr CAfterDark::DrawFrame(RgnHandle blankRgn, GMParamBlockPtr params)
{
	return noErr;
}


/*
 * Close does nothing.  Subclasses should override this method
 * to release any memory allocated by their subclass and to clean
 * things up before closing.  NOTE: you shouldn't delete the
 * instance of your object (i.e., this).
 */
 
OSErr CAfterDark::Close(RgnHandle blankRgn, GMParamBlockPtr params)
{
	return noErr;
}


/*
 * SetUp does nothing.  Subclasses should override this method to
 * handle button messages.
 */ 
OSErr CAfterDark::SetUp(RgnHandle blankRgn, short message, GMParamBlockPtr params)
{
	return noErr;
}